from setuptools import setup, find_packages
setup(
    name="pyfuckfurry",
    version="1.0",
    description="libraly blyat.",
    author="ANUSIXA66383",
    author_email="whonix777890@proton.me",
    packages=find_packages(),
)
